==> bulmages_0.9.1.orig.tar.gz: bulmages-0.9.1/bulmages/bulmafact/src/informereferencia.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Tomeu Borras Riera                              *
 *   tborras@conetxia.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef __INFORMEREFERENCIA__
#define __INFORMEREFERENCIA__

#include <QString>


class company;


/// Genera un informe utilizando una referencia.
/** */
class InformeReferencia {
private:
    QString m_referencia;
    company* companyact;

public:
    InformeReferencia(company *);
    ~InformeReferencia();
    void setreferencia(QString val) {
        m_referencia = val;
    };
    void generarinforme();
};


/// Genera un informe utilizando un identificador de cliente.
/** */
class InformeCliente {
private:
    QString m_idcliente;
    company* companyact;

public:
    InformeCliente(company *);
    ~InformeCliente();
    void setCliente(QString val) {
        m_idcliente = val;
    };
    void generarInforme();
};


/// Genera un informe de todos los cliente.
/** */
class InformeClientes {
private:
    company* companyact;

public:
    InformeClientes(company *);
    ~InformeClientes();
    void generarInforme();
    QString generarCliente(QString);
};

#endif

==> bulmages_0.11.1.orig.tar.gz: bulmages-0.11.1/bulmages/bulmafact/src/informereferencia.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Tomeu Borras Riera                              *
 *   tborras@conetxia.com                                                  *
 *   http://www.iglues.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef __INFORMEREFERENCIA__
#define __INFORMEREFERENCIA__

#include <QString>


class Company;

/// Genera un informe utilizando un identificador de cliente.
/** */
class InformeCliente
{
private:
    QString m_idcliente;
    Company* companyact;

public:
    InformeCliente ( Company * );
    ~InformeCliente();
    void setCliente ( QString );
    void generarInforme();
};

#endif
